<?php

use QUI\Permissions\Exception as QUIPermissionException;
use QUI\Verification\Controls\AddressVerification;

/** @var QUI\Projects\Project $Project */
/** @var QUI\Projects\Site $Site */
/** @var QUI\Interfaces\Template\EngineInterface $Engine */

function redirect(string $target): never
{
    header('Location: ' . $target);
    exit;
}

$User = QUI::getUserBySession();

// User must be authenticated; if not -> throw permission exception so QUIQQER shows the login form
if (!QUI::getUsers()->isAuth($User)) {
    throw new QUIPermissionException("Please authenticate.", 401);
}

if (empty($_GET['id'])) {
    redirect('/');
}

$errorMsg = null;

try {
    $addressVerification = new AddressVerification($_GET['id']);
} catch (\Exception $exception) {
    QUI\System\Log::writeException($exception);

    $errorMsg = QUI::getLocale()->get(
        'quiqqer/verification',
        'message.types.verifyAddress.error.general'
    );
}

$Engine->assign([
    'errorMsg' => $errorMsg,
    'addressVerificationControl' => $addressVerification ?? null
]);
